@@ -190,31 +190,33 @@ class VehicleClient:
         """
         return self.client.call("simSwapTextures", tags, tex_id, component_id, material_id)
 
-    def simSetObjectMaterial(self, object_name, material_name):
+    def simSetObjectMaterial(self, object_name, material_name, component_id = 0):
         """
         Runtime Swap Texture API
         See https://microsoft.github.io/AirSim/retexturing/ for details
         Args:
             object_name (str): name of object to set material for
             material_name (str): name of material to set for object
+            component_id (int, optional) : index of material elements
 
         Returns:
             bool: True if material was set
         """
-        return self.client.call("simSetObjectMaterial", object_name, material_name)
+        return self.client.call("simSetObjectMaterial", object_name, material_name, component_id)
 
-    def simSetObjectMaterialFromTexture(self, object_name, texture_path):
+    def simSetObjectMaterialFromTexture(self, object_name, texture_path, component_id = 0):
         """
         Runtime Swap Texture API
         See https://microsoft.github.io/AirSim/retexturing/ for details
         Args:
             object_name (str): name of object to set material for
             texture_path (str): path to texture to set for object
+            component_id (int, optional) : index of material elements
 
         Returns:
             bool: True if material was set
         """
-        return self.client.call("simSetObjectMaterialFromTexture", object_name, texture_path)
+        return self.client.call("simSetObjectMaterialFromTexture", object_name, texture_path, component_id)
 
 
     # time-of-day control
@@ -459,6 +461,8 @@ class VehicleClient:
 
     def simGetVehiclePose(self, vehicle_name = ''):
         """
+        The position inside the returned Pose is in the frame of the vehicle's starting point
+        
         Args:
             vehicle_name (str, optional): Name of the vehicle to get the Pose of
 
@@ -483,6 +487,8 @@ class VehicleClient:
 
     def simGetObjectPose(self, object_name):
         """
+        The position inside the returned Pose is in the world frame
+
         Args:
             object_name (str): Object to get the Pose of
 
@@ -789,6 +795,8 @@ class VehicleClient:
         """
         Get Ground truth kinematics of the vehicle
 
+        The position inside the returned KinematicsState is in the frame of the vehicle's starting point
+
         Args:
             vehicle_name (str, optional): Name of the vehicle
 
@@ -816,6 +824,8 @@ class VehicleClient:
         """
         Get ground truth environment state
 
+        The position inside the returned EnvironmentState is in the frame of the vehicle's starting point
+
         Args:
             vehicle_name (str, optional): Name of the vehicle
 
@@ -1182,10 +1192,12 @@ class MultirotorClient(VehicleClient, object):
         return self.client.call_async('moveByVelocityZBodyFrame', vx, vy, z, duration, drivetrain, yaw_mode, vehicle_name)
 
     def moveByAngleZAsync(self, pitch, roll, z, yaw, duration, vehicle_name = ''):
-        return self.client.call_async('moveByAngleZ', pitch, roll, z, yaw, duration, vehicle_name)
+        logging.warning("moveByAngleZAsync API is deprecated, use moveByRollPitchYawZAsync() API instead")
+        return self.client.call_async('moveByRollPitchYawZ', roll, -pitch, -yaw, z, duration, vehicle_name)
 
     def moveByAngleThrottleAsync(self, pitch, roll, throttle, yaw_rate, duration, vehicle_name = ''):
-        return self.client.call_async('moveByAngleThrottle', pitch, roll, throttle, yaw_rate, duration, vehicle_name)
+        logging.warning("moveByAngleThrottleAsync API is deprecated, use moveByRollPitchYawrateThrottleAsync() API instead")
+        return self.client.call_async('moveByRollPitchYawrateThrottle', roll, -pitch, -yaw_rate, throttle, duration, vehicle_name)
 
     def moveByVelocityAsync(self, vx, vy, vz, duration, drivetrain = DrivetrainType.MaxDegreeOfFreedom, yaw_mode = YawMode(), vehicle_name = ''):
         """
@@ -1544,6 +1556,8 @@ class MultirotorClient(VehicleClient, object):
 #query vehicle state
     def getMultirotorState(self, vehicle_name = ''):
         """
+        The position inside the returned MultirotorState is in the frame of the vehicle's starting point
+
         Args:
             vehicle_name (str, optional): Vehicle to get the state of
 
@@ -1584,6 +1598,8 @@ class CarClient(VehicleClient, object):
 
     def getCarState(self, vehicle_name = ''):
         """
+        The position inside the returned CarState is in the frame of the vehicle's starting point
+
         Args:
             vehicle_name (str, optional): Name of vehicle
 
@@ -1602,4 +1618,4 @@ class CarClient(VehicleClient, object):
             CarControls:
         """
         controls_raw = self.client.call('getCarControls', vehicle_name)
-        return CarControls.from_msgpack(controls_raw)
+        return CarControls.from_msgpack(controls_raw)
\ No newline at end of file
